@@ -2,7 +2,7 @@ import os
 from os.path import join, isfile
 
 from tests.test_kim_property import PyTest
-from kim_property.create import property_id_to_property_name
+from kim_property.create import PROPERTY_ID_TO_PROPERTY_NAME
 
 SOURCE_VALUE = [
     [0, 0, 0, 0, 0, 0, ],
@@ -63,7 +63,7 @@ class TestPropertyInstanceModuleComponents:
             _, _, _, _property_name = self.kim_property.get_property_id_path(
                 k)
 
-            property_name = property_id_to_property_name[k]
+            property_name = PROPERTY_ID_TO_PROPERTY_NAME[k]
             self.assertTrue(_property_name == property_name)
 
     def test_check_instance_id_format(self):
@@ -239,11 +239,16 @@ class TestPropertyInstanceModuleComponents:
                           self.kim_property.check_instance_optional_key_standard_pairs_format,
                           {"source-value": [3.9149, 3.149], "source-unit": "angstrom", "digits": 5}, {"type": "float", "has-unit": True, "extent": [], "required": True})
 
-        # "source-unit" is required but is not there
+        # "extent" dimension does not match with "source-unit" dimension
         self.assertRaises(self.KIMPropertyError,
                           self.kim_property.check_instance_optional_key_standard_pairs_format,
                           {"source-value": [3.9149], "digits": 5}, {"type": "float", "has-unit": True, "extent": [2], "required": True})
 
+        # "source-unit" is required but is not there
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.check_instance_optional_key_standard_pairs_format,
+                          {"source-value": [3.9149, 3.149], "digits": 5}, {"type": "float", "has-unit": True, "extent": [2], "required": True})
+
         # Fail for a wrong key in standard key-value pairs
         self.assertRaises(self.KIMPropertyError,
                           self.kim_property.check_instance_optional_key_standard_pairs_format,
@@ -291,7 +296,7 @@ class TestPropertyInstanceModuleComponents:
         self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
                           pi, pd)
 
-        # Fails if the path KIM properties is not bsolute
+        # Fails if the path KIM properties is not absolute
         self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
                           pi, fp=None, fp_path="cohesive-energy-relation-cubic-crystal.edn")
 
@@ -299,6 +304,14 @@ class TestPropertyInstanceModuleComponents:
         self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
                           pi, fp=None, fp_path=[])
 
+        pd = {"property-id": "tag:staff@noreply.openkim.org,2014-04-15:property/cohesive-energy-relation-cubic-crystal",
+              "property-title": "Cohesive energy versus lattice constant relation for a cubic crystal",
+              "property-description": "Cohesive energy versus lattice constant relation for a cubic crystal at zero absolute temperature."}
+
+        # Fails if both fp and fpath exists
+        self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
+                          pi, fp=pd, fp_path="cohesive-energy-relation-cubic-crystal.edn")
+
 
 property_instance_names = [
     "RD_000018659700_000_data.edn",
