@@ -91,6 +91,20 @@ class TestModifyModule:
             "source-unit", "eV",
             "digits", "5")
 
+        # Test on different order inputs
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "digits", "5",
+            "source-unit", "eV")
+
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "digits", "5",
+            "key", "basis-atom-coordinates",
+            "source-value", "3", "1", "0.5")
+
         kim_obj = kim_edn.load(str_obj)[0]
 
         self.assertTrue(Property_Instance == kim_edn.dumps(kim_obj))
@@ -114,6 +128,27 @@ class TestModifyModule:
 
         self.assertTrue(kim_obj["space-group"]["source-value"] == "Fm-3m")
 
+        # Test for scalar values with no extent
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "source-unit", "eV")
+
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "source-unit", "eV-test")
+
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "si-unit", "eV")
+
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1,
+            "key", "cohesive-potential-energy",
+            "si-unit", "eV-test")
+
     def test_modify_exception(self):
         """Test the modify functionality on exceptions."""
         # Fails when the input is none or not created
@@ -343,6 +378,14 @@ class TestModifyModule:
                           str_obj, 1,
                           "key", "cohesive-potential-energy", "digits", 1, 5)
 
+        str_obj = self.kim_property.kim_property_modify(
+            str_obj, 1, "key", "a", "digits", 3)
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_modify,
+                          str_obj, 1,
+                          "key", "a", "digits", 3.14, "key", "a", "source-value", 3.14)
+
         # Create the property instance with the property name
         str_obj = self.kim_property.kim_property_create(
             1, 'cohesive-energy-relation-cubic-crystal')
@@ -431,6 +474,12 @@ class TestModifyModule:
                           "key", "a",
                           "digits", "1:5")
 
+        # Fails paasing the wrong type
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_modify, str_obj, 1,
+                          "key", "a", "digits", 5.1, "key",
+                          "basis-atom-coordinates", "source-value", "1:2", "1", 0.5, 0.5)
+
         # Fails when not enough input
         self.assertRaises(self.KIMPropertyError,
                           self.kim_property.kim_property_modify, str_obj, 1,
@@ -613,20 +662,20 @@ class TestModifyModule:
 
         str_obj = self.kim_property.kim_property_modify(
             str_obj, 1,
-            "key", "core-energy",
+            "key", "core-energy-nonsingular",
             "source-value", "1:9", *E_core_nonsingular_avg,
             "source-asym-std-uncert-neg", "1:9", *E_core_nonsingular_min)
 
         str_obj = self.kim_property.kim_property_modify(
             str_obj, 1,
-            "key", "core-energy",
+            "key", "core-energy-nonsingular",
             "source-asym-std-uncert-pos", "1:9", *E_core_nonsingular_max)
 
         kim_obj = kim_edn.load(str_obj)
         for i in range(9):
-            self.assertTrue(kim_obj[0]["core-energy"]
+            self.assertTrue(kim_obj[0]["core-energy-nonsingular"]
                             ["source-asym-std-uncert-neg"][i] == E_core_nonsingular_min[i])
-            self.assertTrue(kim_obj[0]["core-energy"]
+            self.assertTrue(kim_obj[0]["core-energy-nonsingular"]
                             ["source-asym-std-uncert-pos"][i] == E_core_nonsingular_max[i])
 
 
